@@ -34,9 +34,6 @@ G_DEFINE_ABSTRACT_TYPE_WITH_CODE(TangleActor, tangle_actor, CLUTTER_TYPE_ACTOR,
                                  G_IMPLEMENT_INTERFACE(CLUTTER_TYPE_SCRIPTABLE, clutter_scriptable_iface_init););
 
 struct _TangleActorPrivate {
-	TangleTemplate* template;
-	gboolean template_applied;
-
 	gfloat transition_move_x;
 	gfloat transition_move_y;
 	gdouble transition_scale_x;
@@ -88,7 +85,8 @@ struct _TangleActorPrivate {
 	
 	ClutterTimeline* hiding_timeline;
 	
-	ClutterScript* script;
+	GHashTable* template_parameters;
+	gboolean template_found;
 
 	guint transition_scale_children : 1;
 	guint margin_set : 1;
@@ -168,7 +166,6 @@ static void unset_transition_scale_children(TangleActor* actor);
 static void on_hiding_timeline_completed(TangleActor* actor);
 static void setup_animation_valist(ClutterAnimation* animation, TangleActor* actor, const gchar* first_property_name, va_list args);
 static void setup_animation_array(ClutterAnimation* animation, TangleActor* actor, gint n_properties, const gchar* const property_names[], const GValue* property_values);
-static gboolean check_template_parameters(gpointer user_data);
 static void complete_timeline(ClutterTimeline* timeline);
 
 static guint signals[LAST_SIGNAL] = { 0 };
@@ -832,25 +829,6 @@ void tangle_actor_handle_descendant_event(TangleActor* actor, TangleEvent* event
 	}
 }
 
-gchar* tangle_actor_lookup_filename(TangleActor* actor, const gchar* filename) {
-
-	return _tangle_script_lookup_filename(actor->priv->script, filename);
-}
-
-ClutterScript* tangle_actor_get_script(TangleActor* actor) {
-
-	return actor->priv->script;
-}
-
-void _tangle_actor_set_script(TangleActor* actor, ClutterScript* script) {
-	g_return_if_fail(TANGLE_IS_ACTOR(actor));
-	g_return_if_fail(CLUTTER_IS_SCRIPT(script));
-	g_return_if_fail(!actor->priv->script);
-	
-	actor->priv->script = script;
-	g_object_add_weak_pointer(G_OBJECT(actor->priv->script), (gpointer*)&actor->priv->script);
-}
-
 TangleSpacing* tangle_spacing_new(gfloat top, gfloat right, gfloat bottom, gfloat left) {
 	TangleSpacing* spacing;
 	
@@ -1292,14 +1270,7 @@ static void tangle_actor_set_property(GObject* object, guint prop_id, const GVal
 	switch (prop_id) {
 		case PROP_TEMPLATE:
 			if (g_value_get_object(value) != NULL) {
-				g_return_if_fail(!actor->priv->template);
-				actor->priv->template = TANGLE_TEMPLATE(g_value_get_object(value));
-				g_object_ref(actor->priv->template);
-				if (tangle_template_has_parameters(actor->priv->template)) {
-					g_idle_add_full(G_PRIORITY_HIGH, check_template_parameters, object, NULL);
-				} else {
-					tangle_template_apply_properties(actor->priv->template, object);
-				}
+				tangle_template_apply_properties(TANGLE_TEMPLATE(g_value_get_object(value)), object);
 			}
 			break;
 		case PROP_TRANSITION_MOVE_X:
@@ -1557,11 +1528,11 @@ static void tangle_actor_dispose(GObject* object) {
 	}
 	TANGLE_ACTOR_UNSET_FLAGS(actor, TANGLE_ACTOR_HIDING);
 	
-	if (actor->priv->script) {
-		g_object_remove_weak_pointer(G_OBJECT(actor->priv->script), (gpointer*)&actor->priv->script);
-		actor->priv->script = NULL;
+	if (actor->priv->template_parameters) {
+		g_hash_table_destroy(actor->priv->template_parameters);
+		actor->priv->template_parameters = NULL;
 	}
-
+	
 	G_OBJECT_CLASS (tangle_actor_parent_class)->dispose (object);
 }
 
@@ -1597,13 +1568,15 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 
 	/**
 	 * TangleActor:template:
+	 *
+	 * Applies the given #TangleTemplate to this actor.
 	 */
 	g_object_class_install_property(gobject_class, PROP_TEMPLATE,
 	                                g_param_spec_object("template",
 	                                "Template",
-	                                "A template that is used to construct the properties of this object",
+	                                "Applies the given template to this actor",
 	                                TANGLE_TYPE_TEMPLATE,
-	                                G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	                                G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleActor:transition-move-x:
 	 */
@@ -1976,13 +1949,8 @@ static gboolean tangle_actor_parse_custom_node(ClutterScriptable* scriptable, Cl
 	TangleActor* actor;
 
 	actor = TANGLE_ACTOR(scriptable);
-	g_return_val_if_fail(!actor->priv->script || actor->priv->script == script, FALSE);
 
-	if (!actor->priv->script) {
-		_tangle_actor_set_script(actor, script);
-	}
-
-	if (!(retvalue = _tangle_scriptable_parse_custom_node(scriptable, script, value, name, node, actor->priv->template, &actor->priv->template_applied)) &&
+	if (!(retvalue = _tangle_scriptable_parse_custom_node(scriptable, script, value, name, node, &actor->priv->template_parameters, &actor->priv->template_found)) &&
 	    parent_scriptable_iface->parse_custom_node) {
 		retvalue = parent_scriptable_iface->parse_custom_node(scriptable, script, value, name, node);
 	}
@@ -1991,7 +1959,11 @@ static gboolean tangle_actor_parse_custom_node(ClutterScriptable* scriptable, Cl
 }
 
 static void tangle_actor_set_custom_property(ClutterScriptable* scriptable, ClutterScript* script, const gchar* name, const GValue* value) {
-	_tangle_scriptable_set_custom_property(scriptable, script, name, value);
+	TangleActor* actor;
+
+	actor = TANGLE_ACTOR(scriptable);
+	
+	_tangle_scriptable_set_custom_property(scriptable, script, name, value, &actor->priv->template_parameters, actor->priv->template_found);
 }
 
 static void clutter_scriptable_iface_init(ClutterScriptableIface* iface) {
@@ -2241,18 +2213,6 @@ static void setup_animation_array(ClutterAnimation* animation, TangleActor* acto
 	clutter_timeline_start(clutter_animation_get_timeline(animation));
 }
 
-static gboolean check_template_parameters(gpointer user_data) {
-	TangleActor* actor;
-	
-	actor = TANGLE_ACTOR(user_data);
-	
-	if (actor->priv->template && !actor->priv->template_applied) {
-		g_critical("Some template (id: %s) parameters in actor (id: %s) are missing. Template is not used.", clutter_get_script_id(G_OBJECT(actor->priv->template)), clutter_get_script_id(G_OBJECT(actor)));
-	}
-	
-	return FALSE;
-}
-
 static void complete_timeline(ClutterTimeline* timeline) {
 	clutter_timeline_skip(timeline, clutter_timeline_get_duration(timeline) - clutter_timeline_get_elapsed_time(timeline));
 }
