@@ -57,7 +57,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data);
 static void on_animation_completed(ClutterAnimation* animation, gpointer user_data);
 static void handle_droppable_actor(TangleDragging* dragging);
-static void send_interaction_event(TangleActor* actor, gboolean began);
 
 ClutterActor* tangle_draggable_actor_new(ClutterActor* wrapped) {
 
@@ -441,7 +440,7 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 		if (draggable_actor->priv->dragging_effective) {
 			handle_droppable_actor(draggable_actor->priv->dragging);
 			if (event->type == CLUTTER_BUTTON_RELEASE) {
-				send_interaction_event(TANGLE_ACTOR(draggable_actor), FALSE);
+				tangle_actor_send_interaction_ended_event(TANGLE_ACTOR(draggable_actor), TRUE, TRUE, TRUE);
 			}
 			g_signal_emit(draggable_actor, signals[(event->type == CLUTTER_MOTION ? DO_DRAGGING : END_DRAGGING)], 0, draggable_actor->priv->dragging, &handled);
 			if (event->type == CLUTTER_BUTTON_RELEASE) {
@@ -460,7 +459,7 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 				handle_droppable_actor(draggable_actor->priv->dragging);
 				g_signal_emit(draggable_actor, signals[BEGIN_DRAGGING], 0, draggable_actor->priv->dragging, &handled);	
 				if (handled) {
-					send_interaction_event(TANGLE_ACTOR(draggable_actor), TRUE);
+					tangle_actor_send_interaction_began_event(TANGLE_ACTOR(draggable_actor), TRUE, TRUE, TRUE);
 				}
 			}
 			if (event->type == CLUTTER_BUTTON_RELEASE || !handled) {
@@ -523,15 +522,3 @@ static void handle_droppable_actor(TangleDragging* dragging) {
 		}
 	}
 }
-
-static void send_interaction_event(TangleActor* actor, gboolean began) {
-	TangleEvent* event;
-
-	event = tangle_event_new((began ? TANGLE_EVENT_INTERACTION_BEGAN : TANGLE_EVENT_INTERACTION_ENDED),
-	                         TANGLE_ACTOR(actor));
-	event->interaction.x_axis = TRUE;
-	event->interaction.y_axis = TRUE;
-	event->interaction.dragging = TRUE;
-	tangle_actor_send_event(actor, event);
-	tangle_event_free(event);
-}
