@@ -326,15 +326,16 @@ static void tangle_properties_init(TangleProperties* properties) {
 	properties->priv->hash_table = g_hash_table_new_full(g_str_hash, g_str_equal, free_str_slice, free_g_value_slice);
 }
 
-static gboolean tangle_properties_parse_custom_node(ClutterScriptable* scriptable, ClutterScript* script, GValue* value, const gchar* name, JsonNode* node) {
-
-	_tangle_object_set_script(TANGLE_OBJECT(scriptable), script);
-
-	return clutter_script_parse_node(script, value, name, node, NULL);
-}
-
 static void tangle_properties_set_custom_property(ClutterScriptable* scriptable, ClutterScript* script, const gchar* name, const GValue* value) {
-	tangle_properties_set_property(TANGLE_PROPERTIES(scriptable), name, value);	
+	if (g_object_class_find_property(G_OBJECT_GET_CLASS(G_OBJECT(scriptable)), name)) {
+		if (parent_scriptable_iface->set_custom_property) {
+			parent_scriptable_iface->set_custom_property(scriptable, script, name, value);
+		} else {
+			g_object_set_property(G_OBJECT(scriptable), name, value);
+		}
+	} else {
+		tangle_properties_set_property(TANGLE_PROPERTIES(scriptable), name, value);	
+	}
 }
 
 static void clutter_scriptable_iface_init(ClutterScriptableIface* iface) {
@@ -342,7 +343,6 @@ static void clutter_scriptable_iface_init(ClutterScriptableIface* iface) {
 		parent_scriptable_iface = g_type_default_interface_peek(CLUTTER_TYPE_SCRIPTABLE);
 	}
 	
-	iface->parse_custom_node = tangle_properties_parse_custom_node;
 	iface->set_custom_property = tangle_properties_set_custom_property;
 }
 
