@@ -275,19 +275,17 @@ void tangle_widget_set_background_actor(TangleWidget* widget, ClutterActor* acto
 	ClutterActorBox actor_box;
 
 	if (widget->priv->background_actor != actor) {
-		if (actor) {
-			g_object_ref_sink(actor);
-		}
 		if (widget->priv->background_actor) {
 			clutter_actor_unparent(widget->priv->background_actor);
-			g_object_unref(widget->priv->background_actor);
 		}
 		widget->priv->background_actor = actor;
 		
 		if (actor) {
 			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
 			clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
+			clutter_actor_push_internal(CLUTTER_ACTOR(widget));
 			clutter_actor_set_parent(actor, CLUTTER_ACTOR(widget));	
+			clutter_actor_pop_internal(CLUTTER_ACTOR(widget));
 		}
 		
 		g_object_notify(G_OBJECT(widget), "background-actor");
@@ -330,19 +328,17 @@ void tangle_widget_set_foreground_actor(TangleWidget* widget, ClutterActor* acto
 	ClutterActorBox actor_box;
 
 	if (widget->priv->foreground_actor != actor) {
-		if (actor) {
-			g_object_ref_sink(actor);
-		}
 		if (widget->priv->foreground_actor) {
 			clutter_actor_unparent(widget->priv->foreground_actor);
-			g_object_unref(widget->priv->foreground_actor);
 		}
 		widget->priv->foreground_actor = actor;
 		
 		if (actor) {
 			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
 			clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
+			clutter_actor_push_internal(CLUTTER_ACTOR(widget));
 			clutter_actor_set_parent(actor, CLUTTER_ACTOR(widget));	
+			clutter_actor_pop_internal(CLUTTER_ACTOR(widget));
 		}
 		
 		g_object_notify(G_OBJECT(widget), "foreground-actor");
@@ -814,16 +810,14 @@ static void tangle_widget_dispose(GObject* object) {
 		widget->priv->layout = NULL;
 	}
 	
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(widget->priv->stylesheet);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(widget->priv->stylesheet);
 
 	if (widget->priv->background_actor) {
 		clutter_actor_unparent(widget->priv->background_actor);
-		g_object_unref(widget->priv->background_actor);
 		widget->priv->background_actor = NULL;
 	}
 	if (widget->priv->foreground_actor) {
 		clutter_actor_unparent(widget->priv->foreground_actor);
-		g_object_unref(widget->priv->foreground_actor);
 		widget->priv->foreground_actor = NULL;
 	}
 
