@@ -33,6 +33,8 @@ struct _TangleWrapperActorPrivate {
 	ClutterActor* wrapped;
 };
 
+static ClutterScriptableIface* parent_scriptable_iface = NULL;
+
 ClutterActor* tangle_wrapper_actor_new(ClutterActor* wrapped) {
 
 	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_WRAPPER_ACTOR, "wrapped", wrapped, NULL));
@@ -337,25 +339,23 @@ static void clutter_container_iface_init(ClutterContainerIface* iface) {
 
 static void tangle_wrapper_actor_set_custom_property(ClutterScriptable* scriptable, ClutterScript* script,  const gchar* name, const GValue* value) {
 	TangleWrapperActor* wrapper_actor;
-	GParamSpec* param_spec;
-	GObject* object = NULL;
 
 	wrapper_actor = TANGLE_WRAPPER_ACTOR(scriptable);
 
-	if (name[0] != '$' && name[0] != '@') {
-		if ((param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(G_OBJECT(wrapper_actor)), name))) {
-			object = G_OBJECT(wrapper_actor);
-		} else if ((param_spec = g_object_class_find_property(G_OBJECT_GET_CLASS(G_OBJECT(wrapper_actor->priv->wrapped)), name))) {
-			object = G_OBJECT(wrapper_actor->priv->wrapped);
-		} else {
-			g_warning("%s: Neither wrapper nor wrapped actor has property named '%s'.", G_STRLOC, name);
-		}
-		if (object) {
-			g_object_set_property(object, name, value);
-		}
+	if (!g_object_class_find_property(G_OBJECT_GET_CLASS(G_OBJECT(wrapper_actor)), name) &&
+	    g_object_class_find_property(G_OBJECT_GET_CLASS(G_OBJECT(wrapper_actor->priv->wrapped)), name)) {
+		g_object_set_property( G_OBJECT(wrapper_actor->priv->wrapped), name, value);
+	} else if (parent_scriptable_iface->set_custom_property) {
+		parent_scriptable_iface->set_custom_property(scriptable, script, name, value);
+	} else {
+		g_object_set_property(G_OBJECT(scriptable), name, value);
 	}
 }
 
 static void clutter_scriptable_iface_init(ClutterScriptableIface *iface) {
+	if (!(parent_scriptable_iface = parent_scriptable_iface = g_type_interface_peek_parent (iface))) {
+		parent_scriptable_iface = g_type_default_interface_peek(CLUTTER_TYPE_SCRIPTABLE);
+	}
+
 	iface->set_custom_property = tangle_wrapper_actor_set_custom_property;
 }
