@@ -1,12 +1,26 @@
 #include <clutter/clutter.h>
 #include <tangle/tangle.h>
 
-gboolean button1_clicked(TangleButton* button, gpointer user_data) {
+gboolean on_button1_clicked(TangleButton* button, gpointer user_data) {
 	g_printf("Button 1 clicked.\n");
+
+	return FALSE;
 }
 
-gboolean button2_clicked(TangleButton* button, gpointer user_data) {
+gboolean on_button2_clicked(TangleButton* button, gpointer user_data) {
 	g_printf("Button 2 clicked.\n");
+
+	return FALSE;
+}
+
+gboolean on_clicked(TangleButton* button, gpointer user_data) {
+	TangleButton* other_button;
+	
+	other_button = TANGLE_BUTTON(user_data);
+	
+	g_printf("%s clicked (signal connected by %s).\n", clutter_get_script_id(G_OBJECT(other_button)), clutter_get_script_id(G_OBJECT(button)));
+
+	return FALSE;
 }
 
 void on_notify(GObject* object, GParamSpec* param_spec, gpointer user_data) {
